@@ -1,6 +1,6 @@
 #!/home/chrisarg/perl5/perlbrew/perls/current/bin/perl
 package Bit::Set::DB;
-$Bit::Set::DB::VERSION = '0.03';
+$Bit::Set::DB::VERSION = '0.04';
 use strict;
 use warnings;
 use FFI::Platypus::Record;
@@ -9,7 +9,7 @@ use FFI::Platypus::Record;
 {
 
     package Bit::Set::DB::SETOP_COUNT_OPTS;
-$Bit::Set::DB::SETOP_COUNT_OPTS::VERSION = '0.03';
+$Bit::Set::DB::SETOP_COUNT_OPTS::VERSION = '0.04';
 use FFI::Platypus::Record;
     record_layout_1(
         'int'  => 'num_cpu_threads',
@@ -391,7 +391,7 @@ Bit::Set::DB - Perl interface for bitset containers from the C<Bit> C library
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -877,25 +877,47 @@ counts of the intersection of these bitsets to find the maximum popcount via
 
 In the Xeon E-2697v4 I used for this work, I obtained the following benchmarks:
 
-| Test Description                    |   Time (ns)   | Searches/sec | Threads | Result | Speedup |
-|-------------------------------------|---------------|--------------|---------|--------|---------|
-| Bit::Set operations - Rep1          |   388,479,000 |         2.57 |       1 |    512 |    1.00 |
-| Bit::Set operations - Rep2          |   389,512,000 |         2.57 |       1 |    512 |    1.00 |
-| Bit::Set operations - Rep3          |   389,775,000 |         2.57 |       1 |    512 |    1.00 |
-| Container - CPU                     |    82,856,000 |        12.07 |       1 |    512 |    4.69 |
-| Container - CPU                     |    62,179,000 |        16.08 |       2 |    512 |    6.25 |
-| Container - CPU                     |    59,269,000 |        16.87 |       3 |    512 |    6.55 |
-| Container - CPU                     |    61,368,000 |        16.30 |       4 |    512 |    6.33 |
-| Container - GPU                     |   261,441,000 |         3.82 |     GPU |    512 |    1.49 |
-| Container - GPU                     |    62,523,000 |        15.99 |     GPU |    512 |    6.21 |
-| Container - GPU                     |    61,467,000 |        16.27 |     GPU |    512 |    6.32 |
-| Container - CPU - PDL               |    12,559,000 |        79.62 |       1 |    512 |   30.93 |
-| Container - CPU - PDL               |     9,313,000 |       107.38 |       2 |    512 |   41.71 |
-| Container - CPU - PDL               |     5,441,000 |       183.79 |       3 |    512 |   71.40 |
-| Container - CPU - PDL               |     4,457,000 |       224.37 |       4 |    512 |   87.16 |
-| Container - GPU with PDL            |    10,763,000 |        92.91 |     GPU |    512 |   36.09 |
-| Container - GPU with PDL            |     8,662,000 |       115.45 |     GPU |    512 |   44.85 |
-| Container - GPU with PDL            |     8,247,000 |       121.26 |     GPU |    512 |   47.11 |
+=over 5
+
+=item  Test Description                    |   Time (ns)   | Searches/sec | Threads | Result | Speedup |
+
+=item -------------------------------------|---------------|--------------|---------|--------|---------|
+
+=item  Bit::Set operations - Rep1          |   388,479,000 |         2.57 |       1 |    512 |    1.00 |
+
+=item  Bit::Set operations - Rep2          |   389,512,000 |         2.57 |       1 |    512 |    1.00 |
+
+=item  Bit::Set operations - Rep3          |   389,775,000 |         2.57 |       1 |    512 |    1.00 |
+
+=item  Container - CPU                     |    82,856,000 |        12.07 |       1 |    512 |    4.69 |
+
+=item  Container - CPU                     |    62,179,000 |        16.08 |       2 |    512 |    6.25 |
+
+=item  Container - CPU                     |    59,269,000 |        16.87 |       3 |    512 |    6.55 |
+
+=item  Container - CPU                     |    61,368,000 |        16.30 |       4 |    512 |    6.33 |
+
+=item  Container - GPU                     |   261,441,000 |         3.82 |     GPU |    512 |    1.49 |
+
+=item  Container - GPU                     |    62,523,000 |        15.99 |     GPU |    512 |    6.21 |
+
+=item  Container - GPU                     |    61,467,000 |        16.27 |     GPU |    512 |    6.32 |
+
+=item  Container - CPU - PDL               |    12,559,000 |        79.62 |       1 |    512 |   30.93 |
+
+=item  Container - CPU - PDL               |     9,313,000 |       107.38 |       2 |    512 |   41.71 |
+
+=item  Container - CPU - PDL               |     5,441,000 |       183.79 |       3 |    512 |   71.40 |
+
+=item  Container - CPU - PDL               |     4,457,000 |       224.37 |       4 |    512 |   87.16 |
+
+=item  Container - GPU with PDL            |    10,763,000 |        92.91 |     GPU |    512 |   36.09 |
+
+=item  Container - GPU with PDL            |     8,662,000 |       115.45 |     GPU |    512 |   44.85 |
+
+=item  Container - GPU with PDL            |     8,247,000 |       121.26 |     GPU |    512 |   47.11 |
+
+=back
 
 The table clearly illustrates the significant speed up of the containerized 
 operations over the C<Bit::Set>, but also the overhead of using Perl arrays to
